@@ -28,7 +28,7 @@ sub all {
     );
   }
 
-  return $all;
+  return @promises ? $all : $all->resolve;
 }
 
 sub catch { shift->then(undef, shift) }
